# AccessMySQLConverter
AccessMySQLConverter aims to provide a tool which converts MS Access database files (.mdb, .accdb) into a SQL file (and viceversa in future releases) that can be run, generating It's structure and optionally importing It's data
